@@ -608,6 +608,7 @@ module.exports = {
 	"9.3.4": "83.0.4103.122",
 	"9.3.5": "83.0.4103.122",
 	"9.4.0": "83.0.4103.122",
+	"9.4.1": "83.0.4103.122",
 	"10.0.0-beta.1": "84.0.4129.0",
 	"10.0.0-beta.2": "84.0.4129.0",
 	"10.0.0-beta.3": "85.0.4161.2",
@@ -763,6 +764,7 @@ module.exports = {
 	"11.0.5": "87.0.4280.88",
 	"11.1.0": "87.0.4280.88",
 	"11.1.1": "87.0.4280.88",
+	"11.2.0": "87.0.4280.141",
 	"12.0.0-beta.1": "89.0.4328.0",
 	"12.0.0-beta.3": "89.0.4328.0",
 	"12.0.0-beta.4": "89.0.4328.0",
@@ -774,6 +776,7 @@ module.exports = {
 	"12.0.0-beta.10": "89.0.4328.0",
 	"12.0.0-beta.11": "89.0.4328.0",
 	"12.0.0-beta.12": "89.0.4328.0",
+	"12.0.0-beta.14": "89.0.4328.0",
 	"12.0.0-nightly.20200827": "86.0.4234.0",
 	"12.0.0-nightly.20200831": "86.0.4234.0",
 	"12.0.0-nightly.20200902": "86.0.4234.0",
@@ -817,5 +820,8 @@ module.exports = {
 	"13.0.0-nightly.20201221": "89.0.4349.0",
 	"13.0.0-nightly.20201222": "89.0.4349.0",
 	"13.0.0-nightly.20201223": "89.0.4359.0",
-	"13.0.0-nightly.20210104": "89.0.4359.0"
+	"13.0.0-nightly.20210104": "89.0.4359.0",
+	"13.0.0-nightly.20210108": "89.0.4359.0",
+	"13.0.0-nightly.20210111": "89.0.4359.0",
+	"13.0.0-nightly.20210113": "89.0.4386.0"
 };
\ No newline at end of file
